@@ -33,6 +33,7 @@
 #  define KDECORATIONS2_DECL_DEPRECATED_NO_EXPORT KDECORATIONS2_NO_EXPORT KDECORATIONS2_DECL_DEPRECATED
 #endif
 
+/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
 #if 0 /* DEFINE_NO_DEPRECATED */
 #  ifndef KDECORATIONS2_NO_DEPRECATED
 #    define KDECORATIONS2_NO_DEPRECATED
@@ -61,7 +62,7 @@
 #define KDECORATIONS2_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KDECORATIONS2_NO_DEPRECATED
-#  define KDECORATIONS2_DISABLE_DEPRECATED_BEFORE_AND_AT 0x51b08
+#  define KDECORATIONS2_DISABLE_DEPRECATED_BEFORE_AND_AT 0x60104
 #endif
 #ifdef KDECORATIONS2_NO_DEPRECATED_WARNINGS
 #  define KDECORATIONS2_DEPRECATED_WARNINGS_SINCE 0
@@ -71,12 +72,12 @@
 #  ifdef KDECORATIONS2_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KDECORATIONS2_DEPRECATED_WARNINGS_SINCE KDECORATIONS2_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KDECORATIONS2_DEPRECATED_WARNINGS_SINCE 0x51b08
+#    define KDECORATIONS2_DEPRECATED_WARNINGS_SINCE 0x60104
 #  endif
 #endif
 
 #ifndef KDECORATIONS2_DISABLE_DEPRECATED_BEFORE_AND_AT
-#  define KDECORATIONS2_DISABLE_DEPRECATED_BEFORE_AND_AT 0x50000
+#  define KDECORATIONS2_DISABLE_DEPRECATED_BEFORE_AND_AT 0x60000
 #endif
 
 #ifdef KDECORATIONS2_DEPRECATED
